package doctor.controller;

import doctor.common.core.domain.HealthR;
import doctor.common.core.web.controller.BaseController;
import doctor.common.security.utils.SecurityUtils;
import doctor.domain.dto.ApplyJoinDto;
import doctor.domain.dto.CheckCodeDto;
import doctor.domain.entity.Banners;
import doctor.domain.entity.DoctorJobTitleEntity;
import doctor.domain.vo.*;
import doctor.service.BannersService;
import doctor.service.HealthJobTitleService;
import doctor.system.api.model.LoginUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

@RestController
@RequestMapping("/v1")
public class HealthJobTitleController extends BaseController {
    @Autowired
    private HealthJobTitleService healthJobTitleService;

    @Autowired
    private BannersService bannersService;

//    @GetMapping("/findHistoryInquiryRecord")
//    public HealthR<List<DoctorHistoryInquiryVo>> findHistoryInquiryRecord(@RequestHeader Integer doctorId,
//                                                                          @RequestHeader String sessionId,
//                                                                          @RequestParam Integer page,
//                                                                          @RequestParam Integer size) {
//        HealthR<List<DoctorHistoryInquiryVo>> healthR= healthJobTitleService.findHistoryInquiryRecord();
//        return null;
//    }

    @GetMapping("/findDoctorWallet")
    public HealthR<WalletVo> findDoctorWallet(@RequestHeader Integer doctorId,
                                              @RequestHeader String sessionId) {

        WalletVo healthR= healthJobTitleService.findDoctorWallet(doctorId);
        return HealthR.ok(healthR);
    }

    @PostMapping("/drawCash")
    public HealthR drawCash(@RequestHeader Integer doctorId,
                             @RequestHeader String sessionId,
                             @RequestParam Integer money) {
        HealthR healthR= healthJobTitleService.drawCash(doctorId,money);
        return healthR;
    }

    @GetMapping("/findDoctorIncomeRecordList")
    public HealthR<List<DoctorIncomeRecordVo>> findDoctorIncomeRecordList(@RequestHeader Integer doctorId,
                                                                          @RequestHeader String sessionId,
                                                                          @RequestParam Integer page,
                                                                          @RequestParam Integer count) {
        List<DoctorIncomeRecordVo> doctorIncomeRecordEntities=healthJobTitleService.findDoctorIncomeRecordList(doctorId,page,count);
        return HealthR.ok(doctorIncomeRecordEntities);
    }

    @GetMapping("/bannersShow")
    public HealthR<List<Banners>> bannersShow(){
        List<Banners> banners = bannersService.bannersShow();
        return HealthR.ok(banners);
    }

    @GetMapping("/findJobTitleList")
    public HealthR<List<DoctorJobTitleEntity>> findJobTitleList() {
        LoginUser loginUser = SecurityUtils.getLoginUser();
        List<DoctorJobTitleEntity> doctorJobTitleEntities=healthJobTitleService.findJobTitleList();
        return HealthR.ok(doctorJobTitleEntities);
    }

    @RequestMapping("/sendEmailCode")
    public HealthR sendEmailCode(@RequestParam("email") String email) {
        HealthR healthR= healthJobTitleService.sendEmailCode(email);
        return HealthR.ok(healthR);
    }

    @PostMapping("/applyJoin")
    public HealthR applyJoin(@RequestBody ApplyJoinDto applyJoinDto) {
        HealthR healthR= healthJobTitleService.applyJoin(applyJoinDto);
        return HealthR.ok(healthR);
    }

    @PostMapping("/checkCode")
    public HealthR checkCode(@RequestBody CheckCodeDto checkCodeDto) {
        String email = checkCodeDto.getEmail();
        String code = checkCodeDto.getCode();
        HealthR healthR = healthJobTitleService.checkCode(email, code);
        return healthR;
    }

    @GetMapping("/findDoctorById")
    public HealthR<DoctorVo> findDoctorById(@RequestHeader Integer doctorId,
                                            @RequestHeader String sessionId) {
        return HealthR.ok(healthJobTitleService.findDoctorById(doctorId));
    }
    @GetMapping("/findSystemImagePic")
    public HealthR<List<FindImagePicVo>> findSystemImagePic() {
        return HealthR.ok(healthJobTitleService.findSystemImagePic());
    }

    @PostMapping("/uploadImagePic")
    public HealthR uploadImagePic(@RequestParam("imagePic") MultipartFile imagePic,
                                  @RequestHeader String sessionId,
                                  @RequestHeader Integer doctorId) {
        return HealthR.ok(healthJobTitleService.uploadImagePic(imagePic,doctorId,sessionId));
    }

}
